| Title: | VMD Based Time Delay Neural Network Model |
|---|---|
| Description: | Forecasting univariate time series with Variational Mode Decomposition (VMD) based time delay neural network models.For method details see Konstantin, D.and Dominique, Z. (2014). <doi:10.1109/TSP.2013.2288675>. |
| Authors: | Kapil Choudhary [aut, cre], Girish Kumar Jha [aut, ths, ctb], Rajender Parsad [aut, ctb], Ronit Jaiswal [aut, ctb] |
| Maintainer: | Kapil Choudhary <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-05-23 06:09:21 UTC |
| Source: | https://github.com/cran/vmdTDNN |
Monthly international Maize price (Dollor per million ton) from January 2010 to June 2020.
data("Data_Maize")data("Data_Maize")
A time series data with 126 observations.
pricea time series
Dataset contains 126 observations of monthly international Maize price (Dollor per million ton). It is obtained from World Bank "Pink sheet".
https://www.worldbank.org/en/research/commodity-markets
https://www.worldbank.org/en/research/commodity-markets
data(Data_Maize)data(Data_Maize)
The VMDARIMA function computes forecasted value with different forecasting evaluation criteria for Variational Mode Decomposition (VMD) Based Autoregressive Integrated Moving Average (ARIMA).
VMDARIMA (data, stepahead=10, nIMF=4, alpha=2000, tau=0, D=FALSE)VMDARIMA (data, stepahead=10, nIMF=4, alpha=2000, tau=0, D=FALSE)
data |
Input univariate time series (ts) data. |
stepahead |
The forecast horizon. |
nIMF |
The number of IMFs. |
alpha |
The balancing parameter. |
tau |
Time-step of the dual ascent. |
D |
a boolean. |
In this function, the variational mode decomposition (VMD) used for mining the trend features and detailed features contained in a time series. Moreover, the corresponding autoregressive integrated moving average (ARIMA) models were derived to reflect the different features of the IMFs. The final forecasted values obtained for a given time series.
AllIMF |
List of all IMFs with residual for input series. |
data_test |
Testing set used to measure the out of sample performance. |
AllIMF_forecast |
Forecasted value of all individual IMF |
FinalVMDARIMA_forecast |
Final forecasted value of the VMD based ARIMA model. It is obtained by combining the forecasted value of all individual IMF. |
MAE_VMDARIMA |
Mean Absolute Error (MAE) for VMDARIMA model. |
MAPE_VMDARIMA |
Mean Absolute Percentage Error (MAPE) for VMDARIMA model. |
rmse_VMDARIMA |
Root Mean Square Error (RMSE) for VMDARIMA model. |
Box, G. E., Jenkins, G. M., Reinsel, G. C. and Ljung, G. M. (2015). Time series analysis: forecasting and control. John Wiley and Sons.
Dragomiretskiy, K.and Zosso, D. (2014). Variational mode decomposition. IEEE transactions on signal processing, 62(3), 531–544.
Wang, H., Huang, J., Zhou, H., Zhao, L. and Yuan, Y. (2019). An integrated variational mode decomposition and arima model to forecast air temperature. Sustainability, 11(15), 4018.
VMDTDNN,VMDELM
data("Data_Maize") VMDARIMA(Data_Maize)data("Data_Maize") VMDARIMA(Data_Maize)
The VMDELM function computes forecasted value with different forecasting evaluation criteria for Variational Mode Decomposition (VMD) Based Extreme learning machine (ELM).
VMDELM (data, stepahead=10, nIMF=4, alpha=2000, tau=0, D=FALSE)VMDELM (data, stepahead=10, nIMF=4, alpha=2000, tau=0, D=FALSE)
data |
Input univariate time series (ts) data. |
stepahead |
The forecast horizon. |
nIMF |
The number of IMFs. |
alpha |
The balancing parameter. |
tau |
Time-step of the dual ascent. |
D |
a boolean. |
This function decomposes a nonlinear, nonstationary time series into different IMFs using VMD (Qian et al., 2019). Extreme learning machine (ELM) is used to forecast decomposed IMFs individually. Finally, the prediction results of all three components are aggregated to formulate an ensemble output for the input time series.
AllIMF |
List of all IMFs with residual for input series. |
data_test |
Testing set used to measure the out of sample performance. |
AllIMF_forecast |
Forecasted value of all individual IMF |
FinalVMDELM_forecast |
Final forecasted value of the VMD based ELM model. It is obtained by combining the forecasted value of all individual IMF. |
MAE_VMDELM |
Mean Absolute Error (MAE) for VMDELM model. |
MAPE_VMDELM |
Mean Absolute Percentage Error (MAPE) for VMDELM model. |
rmse_VMDELM |
Root Mean Square Error (RMSE) for VMDELM model. |
Dragomiretskiy, K.and Zosso, D. (2014). Variational mode decomposition. IEEE transactions on signal processing, 62(3), 531–544.
Shao, Z., Chao, F., Yang, S. L., & Zhou, K. L. (2017). A review of the decomposition methodology for extracting and identifying the fluctuation characteristics in electricity demand forecasting. Renewable and Sustainable Energy Reviews, 75, 123–136.
Qian, Z., Pei, Y., Zareipour, H. andChen, N. (2019). A review and discussion of decomposition-based hybrid models for wind energy forecasting applications. Applied energy, 235, 939–953.
VMDTDNN,VMDARIMA
data("Data_Maize") VMDELM(Data_Maize)data("Data_Maize") VMDELM(Data_Maize)
The VMDTDNN function computes forecasted value with different forecasting evaluation criteria for Variational Mode Decomposition (VMD) Based Time Delay Neural Network Model (TDNN).
VMDTDNN (data, stepahead=10, nIMF=4, alpha=2000, tau=0,D=FALSE)VMDTDNN (data, stepahead=10, nIMF=4, alpha=2000, tau=0,D=FALSE)
data |
Input univariate time series (ts) data. |
stepahead |
The forecast horizon. |
nIMF |
The number of IMFs. |
alpha |
The balancing parameter. |
tau |
Time-step of the dual ascent. |
D |
a boolean. |
The Variational Mode Decomposition method is a novel adaptive, non-recursive signal decomposition technology, which was introduced by Dragomiretskiy and Zosso (2014). VMD method helps to solve current decomposition methods limitation such as lacking mathematical theory, recursive sifting process which not allows for backward error correction, hard-band limits, the requirement to predetermine filter bank boundaries, and sensitivity to noise. It decomposes a series into sets of IMFs. Time-delay neural networks are used to forecast decomposed components individually (Jha and Sinha, 2014). Finally, the prediction results of all components are aggregated to formulate an ensemble output for the input time series.
AllIMF |
List of all IMFs with residual for input series. |
data_test |
Testing set used to measure the out of sample performance. |
AllIMF_forecast |
Forecasted value of all individual IMF |
FinalVMDTDNN_forecast |
Final forecasted value of the VMD based TDNN model. It is obtained by combining the forecasted value of all individual IMF. |
MAE_VMDTDNN |
Mean Absolute Error (MAE) for VMDTDNN model. |
MAPE_VMDTDNN |
Mean Absolute Percentage Error (MAPE) for VMDTDNN model. |
rmse_VMDTDNN |
Root Mean Square Error (RMSE) for VMDTDNN model. |
Choudhury, K., Jha, G. K., Das, P. and Chaturvedi, K. K. (2019). Forecasting potato price using ensemble artificial neural networks. Indian Journal of Extension Education, 55(1), 73–77.
Choudhary, K., Jha, G. K., Kumar, R. R. and Mishra, D. C. (2019). Agricultural commodity price analysis using ensemble empirical mode decomposition: A case study of daily potato price series. Indian Journal of Agricultural Sciences, 89(5), 882–886.
Dragomiretskiy, K.and Zosso, D. (2014). Variational mode decomposition. IEEE transactions on signal processing, 62(3), 531–544.
Jha, G. K. and Sinha, K. (2014). Time-delay neural networks for time series prediction: An application to the monthly wholesale price of oilseeds in India. Neural Computing and Applications, 24(3–4), 563–571.
VMDARIMA,VMDELM
data("Data_Maize") VMDTDNN(Data_Maize)data("Data_Maize") VMDTDNN(Data_Maize)